﻿function CL_ToggleMod()
	if (CL_SETTINGS["ON"] == 1) then
		CritlineDisplay_UpdateTree("DMG", false)
		CritlineDisplay_UpdateTree("HEAL", false)
		CritlineDisplay_UpdateTree("PET", false)
	else
		CritlineDisplay_UpdateTree("DMG", true)
		CritlineDisplay_UpdateTree("HEAL", true)
		CritlineDisplay_UpdateTree("PET", true)
	end
end

function CritlineDisplay_UpdateTree(tree, enabled)
	local mytree = _G["Critline_Display"..tree]
	local mybutton = _G["Critline_Display"..tree.."Button"]
	Critline_Debug("Critline_Display"..tree.."Button")
	local visiblebuttoncount = 0
	
	local trees = {
		DMG = 8,
		HEAL = 9,
		PET = 10,
	}
	
	if (enabled) then
		CL_SETTINGS["SHOW"..tree] = 1
		Critline_Display:Show()
		Critline_Debug("Show:"..tree)
		mybutton:Show()
		mytree:Show()
	else
		CL_SETTINGS["SHOW"..tree] = 0
		Critline_Debug("Hide:"..tree)
		mybutton:Hide()
		mytree:Hide()
	end
	_G["CritlineSettings_FrameBasic_Option"..trees[tree]]:SetChecked(enabled)
	
	--check for anchors
	local myDMGButton = Critline_DisplayDMGButton
	local myHEALButton = Critline_DisplayHEALButton
	local myPETButton = Critline_DisplayPETButton
	if myHEALButton:IsVisible() then
		myHEALButton:ClearAllPoints()
		if myDMGButton:IsVisible() then
			myHEALButton:SetPoint("TOP", "Critline_DisplayDMGButton", "BOTTOM", 0, -2)
			Critline_Debug("Anchor HEAL to DMG")
		else
			myHEALButton:SetPoint("TOPLEFT", 5, -5)
			Critline_Debug("Anchor HEAL to Parent")
		end
	end
	if myPETButton:IsVisible() then
		myPETButton:ClearAllPoints()
		if myHEALButton:IsVisible() then
			myPETButton:SetPoint("TOP", "Critline_DisplayHEALButton", "BOTTOM", 0, -2)
			Critline_Debug("Anchor PET to HEAL")
		elseif myDMGButton:IsVisible() then
			myPETButton:SetPoint("TOP", "Critline_DisplayDMGButton", "BOTTOM", 0, -2)
			Critline_Debug("Anchor PET to DMG")
		else
			myPETButton:SetPoint("TOPLEFT", 5, -5)
			Critline_Debug("Anchor PET to Parent")
		end
	end
	
	if myDMGButton:IsVisible() then
		visiblebuttoncount = visiblebuttoncount + 1
	end
	if myHEALButton:IsVisible() then
		visiblebuttoncount = visiblebuttoncount + 1
	end
	if myPETButton:IsVisible() then
		visiblebuttoncount = visiblebuttoncount + 1
	end
	
	Critline_Display:SetHeight(visiblebuttoncount * 22 + 8)
	
	
	if not (CL_SETTINGS["SHOWDMG"] == 1 or CL_SETTINGS["SHOWHEAL"] == 1 or CL_SETTINGS["SHOWPET"] == 1) then
		Critline_Display:Hide()
	end
end

function CritlineDisplay_OnLoad(self)
	Critline_OnUpdateRegister(CritlineDisplay_OnUpdate)
	self:RegisterEvent("ADDON_LOADED")
end

function CritlineDisplay_OnEvent(self, event, ...)
	if (event == "ADDON_LOADED" and select(1, ...) == "Critline") then
		CritlineDisplay_OnUpdate()
		Critline_Display:SetScale(CL_SETTINGS["SCALE"])

		local myClass = select(2, UnitClass("player"))
		if (CL_SETTINGS["FIRSTLOAD"] == 1 or CL_SETTINGS["FIRSTLOAD"] == nil) then --by default on first time load, all trees are on
			Critline_Debug("FIRSTLOAD=true")
			Critline_Debug("."..myClass..".")
			local shownTrees = {
				-- CLASS = {dmg, heal, pet}
				DEATHKNIGHT = {true, false, false},
				DRUID = {true, true, false},
				HUNTER = {true, false, true},
				MAGE = {true, false, false},
				PALADIN = {true, true, false},
				PRIEST = {true, true, false},
				ROGUE = {true, false, false},
				SHAMAN = {true, true, false},
				WARLOCK = {true, false, true},
				WARRIOR = {true, false, false},
			}
			for i, tree in ipairs({"DMG", "HEAL", "PET"}) do
				if shownTrees[myClass] then
					CritlineDisplay_UpdateTree(tree, shownTrees[myClass][i])
				end
			end
			CL_SETTINGS["FIRSTLOAD"] = 0
		else --not a first time load, so use user settings to update trees which are still defaulted to on in the CritlineDisplay.xml
			Critline_Debug("FIRSTLOAD=false")
			for i, tree in ipairs({"DMG", "HEAL", "PET"}) do
				CritlineDisplay_UpdateTree(tree, (CL_SETTINGS["SHOW"..tree] == 1 and true or false))
			end
		end
	end 
end

function CritlineDisplay_OnUpdate()
	local rtfText
	for i, tree in ipairs({"DMG", "HEAL", "PET"}) do
		rtfText = strsub("      "..Critline_GetHighest(tree, "NORM"), -6).."/"..strsub(Critline_GetHighest(tree, "CRIT").."      ", 1, 6)	--rtfText will always be 13 chars long with / in the middle..this keeps all numbers aligned
		_G["Critline_Display"..tree]:SetText(rtfText)
		Critline_Debug(rtfText)
	end
end

function Critline_AddTooltipText(text)
	if text then
		-- Append a "\n" to the end 
		if (strsub(text, -1, -1) ~= "\n") then
			text = text.."\n"
		end
		
		for text1, text2 in gmatch(text, "([^\t\n]*)\t?([^\t\n]*)\n") do
			if (text2 ~= "") then
				GameTooltip:AddDoubleLine(text1, text2)
			elseif (text1 ~= "") then
				GameTooltip:AddLine(text1)
			else
				GameTooltip:AddLine("\n")
			end
		end
		GameTooltip:Show()
	end
end